@@ -5,17 +5,17 @@
 # from datetime import datetime, date, time, timedelta
 # from dateutil.parser import parse
 # from pytz import timezone, utc
-from collections import namedtuple
-from .applications import *
-from .subclass import *
+# from collections import namedtuple
+# from .applications import *
+# from .subclass import *
 
 
-import json
-import requests
-import numpy as np
-import pandas as pd
-import os
-from .settings import *
+# import json
+# import requests
+# import numpy as np
+# import pandas as pd
+# import os
+# from .settings import *
 
 
 class Jaye:
@@ -24,7 +24,7 @@ class Jaye:
         self.analysis = analysis()
         self.trade = {}
         self.simulation = simulation()
-        self.version = '0.0.8'
+        self.version = '0.0.9'
 
 
 
